==> puppet-tripleo-7.2.0.tar.gz: openstack-tripleo-7.2.0/spec/classes/tripleo_profile_base_nova_compute_libvirt_spec.rb <==
#
# Copyright (C) 2017 Red Hat, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.
#

require 'spec_helper'

describe 'tripleo::profile::base::nova::compute::libvirt' do
  shared_examples_for 'tripleo::profile::base::nova::compute::libvirt' do

    context 'with step less than 4' do
      let(:params) { { :step => 1, } }

      it {
        is_expected.to contain_class('tripleo::profile::base::nova::compute::libvirt')
        is_expected.to_not contain_class('tripleo::profile::base::nova')
        is_expected.to_not contain_class('tripleo::profile::base::nova::compute')
        is_expected.to_not contain_class('nova::compute::libvirt')
        is_expected.to_not contain_class('nova::compute::libvirt::qemu')
      }
    end

    context 'with step 4' do
      let(:pre_condition) do
        <<-eos
        class { '::tripleo::profile::base::nova':
          step => #{params[:step]},
          oslomsg_rpc_hosts => [ '127.0.0.1' ],
        }
        class { '::tripleo::profile::base::nova::compute':
          step => #{params[:step]},
        }
        class { '::tripleo::profile::base::nova::migration':
          step => #{params[:step]}
        }
        class { '::tripleo::profile::base::nova::migration::client':
          step => #{params[:step]}
        }
eos
      end

      let(:params) { { :step => 4, } }

      it {
        is_expected.to contain_class('tripleo::profile::base::nova::compute::libvirt')
        is_expected.to contain_class('tripleo::profile::base::nova')
        is_expected.to contain_class('tripleo::profile::base::nova::compute')
        is_expected.to contain_class('nova::compute::libvirt')
        is_expected.to contain_class('nova::compute::libvirt::qemu')
      }
    end
  end


  on_supported_os.each do |os, facts|
    context "on #{os}" do
      let(:facts) do
        facts.merge({ :hostname => 'node.example.com' })
      end

      it_behaves_like 'tripleo::profile::base::nova::compute::libvirt'
    end
  end
end

==> puppet-tripleo-10.5.1.tar.gz: openstack-tripleo-10.5.1/spec/classes/tripleo_profile_base_nova_compute_libvirt_spec.rb <==
#
# Copyright (C) 2017 Red Hat, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.
#

require 'spec_helper'

describe 'tripleo::profile::base::nova::compute::libvirt' do
  shared_examples_for 'tripleo::profile::base::nova::compute::libvirt' do

    context 'with step less than 4' do
      let(:params) { { :step => 1, } }

      let(:pre_condition) do
        <<-eos
        class { '::tripleo::profile::base::nova::compute_libvirt_shared':
          step => #{params[:step]},
        }
eos
      end


      it {
        is_expected.to contain_class('tripleo::profile::base::nova::compute::libvirt')
        is_expected.to_not contain_class('tripleo::profile::base::nova')
        is_expected.to_not contain_class('tripleo::profile::base::nova::compute')
        is_expected.to_not contain_class('tripleo::profile::base::nova::migration::client')
        is_expected.to contain_class('tripleo::profile::base::nova::compute_libvirt_shared')
      }
    end

    context 'with step 4' do
      let(:pre_condition) do
        <<-eos
        class { '::tripleo::profile::base::nova':
          step => #{params[:step]},
          oslomsg_rpc_hosts => [ '127.0.0.1' ],
        }
        class { '::tripleo::profile::base::nova::compute_libvirt_shared':
          step => #{params[:step]},
        }
        class { '::tripleo::profile::base::nova::compute':
          step => #{params[:step]},
        }
        class { '::tripleo::profile::base::nova::migration':
          step => #{params[:step]}
        }
        class { '::tripleo::profile::base::nova::migration::client':
          step => #{params[:step]}
        }
eos
      end

      let(:params) { { :step => 4, } }

      it {
        is_expected.to contain_class('tripleo::profile::base::nova::compute::libvirt')
        is_expected.to contain_class('tripleo::profile::base::nova::compute')
        is_expected.to contain_class('tripleo::profile::base::nova::migration::client')
        is_expected.to contain_class('tripleo::profile::base::nova::compute_libvirt_shared')
      }
    end
  end


  on_supported_os.each do |os, facts|
    context "on #{os}" do
      let(:facts) do
        facts.merge({ :hostname => 'node.example.com' })
      end

      it_behaves_like 'tripleo::profile::base::nova::compute::libvirt'
    end
  end
end
